==> snortsms-0.14.9.tbz: www/snortsms/snortctrl/dsp_home.php <==
<?
/***************************************************************************
 *   Copyright (C) 2005 by J Randolph Smith                                *
 *   snortsms@servangle.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

include_once("../lib/func_DrawRepHeader.php");

DrawRepHeader("Snort Daemon Profiles");
?>

<FORM action="index.php?fuseaction=snortctrl.action" method="POST"><div align="center"><table border="0" class="bg1" cellspacing="1" cellpadding="0"><tr><td>

<table border="0" width="100%" class="bg4" cellspacing="0" cellpadding="2"><tr class="combo1"><th nowrap colspan="3">Snort Daemon Profiles</th></tr>
<?
if($rsSCs_total == 0 )
	{
	?>
	<TR><TD align="center" colspan="3"><BR><BR><B>None Defined - Please define some profiles</B><BR><BR><BR></TD></TR>
	<?
	}
else
	{
	while($row=$rsSCs->fetchRow(DB_FETCHMODE_ASSOC))
		{
		$temp_back = ( $temp_back == "bg2" ? "bg4" : "bg2");
		?>
		<tr class="<?=$temp_back?>">
		<td nowrap><input type=checkbox name="FRM_row[]" value="<?=$row['id']?>">	<a href="index.php?fuseaction=snortctrl.edit&FRM_id=<?=$row['id']?>" title="Edit Snort Control"><img src="images/note-1.gif" border="0" width="15" height="16"></a></td>
		<td><?=$row['title']?></td><td><?=$row['interface']?></td>
		</tr>
		<?
		}
	}
?>
</table>


</td></tr><tr><td>


<TABLE border="0" width="100%" class="bg4"><tr><td><B>Action:</B><SELECT name="FRM_action"><OPTION>-Choose Action-</OPTION><OPTION value="Delete">Delete</OPTION></SELECT><INPUT type="submit" value="Submit"></td><td align="right"><a href="index.php?fuseaction=snortctrl.new">[New Snort Profile]</a> </td></tr></table>



</td></tr></table></div></form>

==> snortsms-1.0.0.tbz: www/snortsms/snortctrl/dsp_home.php <==
<?
/***************************************************************************
 *   Copyright (C) 2005 by J Randolph Smith                                *
 *   snortsms@servangle.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

include_once("../lib/func_DrawRepHeader.php");

DrawRepHeader("Snort Daemon Profiles");
?>

<FORM action="index.php?fuseaction=snortctrl.action" method="POST"><div align="center"><table border="0" class="bg1" cellspacing="1" cellpadding="0"><tr><td>

<table border="0" width="100%" class="bg4" cellspacing="0" cellpadding="2"><tr class="combo1"><th nowrap colspan="3">Snort Daemon Profiles</th>
<td align="right">
<a href="#" onclick="help('index.php?fuseaction=help.main&index=snortctrl')"><img src="images/blue_quest.png" width="16" height="14" border="0"></a></td>
</tr>
<?
if($rsSCs_total == 0 )
	{
	?>
	<TR><TD align="center" colspan="4"><BR><BR><B>None Defined - Please define some profiles</B><BR><BR><BR></TD></TR>
	<?
	}
else
	{
	while($row=$rsSCs->fetchRow(DB_FETCHMODE_ASSOC))
		{
		$temp_back = ( $temp_back == "bg2" ? "bg4" : "bg2");
		?>
		<tr class="<?=$temp_back?>">
		<td nowrap><input type=checkbox name="FRM_row[]" value="<?=$row['id']?>">	<a href="index.php?fuseaction=snortctrl.edit&FRM_id=<?=$row['id']?>" title="Edit Snort Control"><img src="images/note-1.gif" border="0" width="15" height="16"></a></td>
		<td><?=$row['title']?></td><td colspan="2"><?=$row['interface']?></td>
		</tr>
		<?
		}
	}
?>
</table>


</td></tr><tr><td>


<TABLE border="0" width="100%" class="bg4"><tr><td><B>Action:</B><SELECT name="FRM_action"><OPTION>-Choose Action-</OPTION><OPTION value="Delete">Delete</OPTION></SELECT><INPUT type="submit" value="Submit"></td><td align="right"><a href="index.php?fuseaction=snortctrl.new">[New Snort Profile]</a> </td></tr></table>



</td></tr></table></div></form>
